@@ -504,16 +504,12 @@ static void
 draw_pixmap (HTMLPainter *painter, GdkPixbuf *pixbuf, gint x, gint y, gint scale_width, gint scale_height, const GdkColor *color)
 {
 	HTMLPrinter *printer;
-	gint width, height;
 	double print_x, print_y;
 	double print_scale_width, print_scale_height;
 
 	printer = HTML_PRINTER (painter);
 	g_return_if_fail (printer->context != NULL);
 
-	width = gdk_pixbuf_get_width (pixbuf);
-	height = gdk_pixbuf_get_height (pixbuf);
-
 	html_printer_coordinates_to_gnome_print (printer, x, y, &print_x, &print_y);
 
 	print_scale_width  = SCALE_ENGINE_TO_GNOME_PRINT (scale_width);
@@ -668,7 +664,7 @@ draw_embedded (HTMLPainter *p, HTMLEmbedded *o, gint x, gint y)
  
 	embedded_widget = html_embedded_get_widget(o);
 	if (embedded_widget && GTK_IS_HTML_EMBEDDED (embedded_widget)) {
-		g_signal_emit_by_name(GTK_OBJECT (embedded_widget), 0,
+		g_signal_emit_by_name(G_OBJECT (embedded_widget),
 				      "draw_print", 
 				      printer->context);
 	}
